summaryrefslogtreecommitdiffstats
path: root/nuttx/configs
diff options
context:
space:
mode:
authorpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-07-09 13:15:44 +0000
committerpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-07-09 13:15:44 +0000
commit314a7005d5efb62fa74337c2263f0f4e90170891 (patch)
tree1f19d3455be3e7d9b078969441a63213c868340d /nuttx/configs
parent59ebc73cce8e5f6bb8ef29b48920df161601c916 (diff)
Update3 LPC4330 README files
git-svn-id: https://nuttx.svn.sourceforge.net/svnroot/nuttx/trunk@4921 7fd9a85b-ad96-42d3-883c-3090e2eb8679
Diffstat (limited to 'nuttx/configs')
-rw-r--r--nuttx/configs/lpc4330-xplorer/README.txt43
-rwxr-xr-xnuttx/configs/lpc4330-xplorer/ostest/setenv.sh14
-rwxr-xr-xnuttx/configs/lpcxpresso-lpc1768/README.txt3
3 files changed, 51 insertions, 9 deletions
diff --git a/nuttx/configs/lpc4330-xplorer/README.txt b/nuttx/configs/lpc4330-xplorer/README.txt
index b319a75370..25eac7c2c2 100644
--- a/nuttx/configs/lpc4330-xplorer/README.txt
+++ b/nuttx/configs/lpc4330-xplorer/README.txt
@@ -273,17 +273,50 @@ Code Red IDE
Command Line Flash Programming
------------------------------
- The GCC toolchain in LPCXpresso can be used from the command line. The
- GDB configuration details for command line use are on Code Red Wiki:
+ The underlying debugger within Red Suite/LPCXpresso is GDB. That GDB
+ used from the command line. The GDB configuration details for command
+ line use are on Code Red Wiki:
http://support.code-red-tech.com/CodeRedWiki/UsingGDB
- The driver for the LPC18xx and LPC43xx is (in my installation path):
+ and is also summarized here (see the full Wiki for additional details
+ and optins).
+
+ The Code Red Debug Driver implements the GDB "remote" protocol to allow
+ connection to debug targets. To start a debug session using GDB, use
+ following steps:
+
+ arm-none-eabi-gdb executable.axf : Start GDB and name the debug image
+ target extended-remote | <debug driver> <options> : Start debug driver, connect to target
+ load : Load image and download to target
+
+ The where <debug driver> is crt_emu_lpc18_43_nxp for LPC18xx and LPC43xx.
+ Your PATH variable should be set up so that the debug driver executable
+ can be found. For my installation, the driver for the LPC18xx and LPC43xx
+ is located at:
/cygdrive/c/code_red/RedSuite_4.2.3_379/redsuite/bin/crt_emu_lpc18_43_nxp.exe
- The 128K free version only supports the LPC-Link and RedProbe debug probes.
- Other JTAG interfaces are supported in the full version.
+ And <options> are:
+
+ -n set information level for the debug driver. n should be 2, 3 or 4.
+ 2 should be sufficient in most circumstances
+
+ -p<part> is the target device to connect to and you should use
+ <part>=LPC4330.
+
+ -wire=<probe> specifies the debug probe. For LPCLink on Windows 7 use
+ <probe>=winusb. The 128K free version only supports the LPC-Link
+ and RedProbe debug probes. Other JTAG interfaces are supported in
+ the full version.
+
+ Thus the correct invocation for the LPC4330 under Windows7 would be:
+
+ target extended-remote | crt_emu_lpc18_43_nxp -2 -pLPC4330 -wire=winusb
+
+ NOTE: Don't forget to enable CONFIG_DEBUG_SYMBOLS=y in your NuttX
+ configuration file when you build NuttX. That option is necessary to build
+ in debugging symbols.
NuttX buildroot Toolchain
=========================
diff --git a/nuttx/configs/lpcxpresso-lpc1768/README.txt b/nuttx/configs/lpcxpresso-lpc1768/README.txt
index 9df5648dc0..b0ead543f4 100755
--- a/nuttx/configs/lpcxpresso-lpc1768/README.txt
+++ b/nuttx/configs/lpcxpresso-lpc1768/README.txt
@@ -307,8 +307,7 @@ Code Red IDE
^^^^^^^^^^^^
NuttX is built using command-line make. It can be used with an IDE, but some
- effort will be required to create the project (There is a simple RIDE project
- in the RIDE subdirectory).
+ effort will be required to create the project.
Makefile Build
--------------
diff --git a/nuttx/configs/lpc4330-xplorer/ostest/setenv.sh b/nuttx/configs/lpc4330-xplorer/ostest/setenv.sh
index c2e0325d59..91c8d73c41 100755
--- a/nuttx/configs/lpc4330-xplorer/ostest/setenv.sh
+++ b/nuttx/configs/lpc4330-xplorer/ostest/setenv.sh
@@ -52,11 +52,13 @@ fi
# Code Red toolchain in any other location or if you install a different
# version
export TOOLCHAIN_BIN="/cygdrive/c/code_red/RedSuite_4.2.3_379/redsuite/Tools/bin"
+export REDSUITE_BIN="/cygdrive/c/code_red/RedSuite_4.2.3_379/redsuite/bin"
# This the Cygwin path to the location where I installed the CodeSourcery
# toolchain under windows. You will also have to edit this if you install
# the CodeSourcery toolchain in any other location
#export TOOLCHAIN_BIN="/cygdrive/c/Program Files (x86)/CodeSourcery/Sourcery G++ Lite/bin"
+#export REDSUITE_BIN=
# These are the Cygwin paths to the locations where I installed the Atollic
# toolchain under windows. You will also have to edit this if you install
@@ -65,12 +67,20 @@ export TOOLCHAIN_BIN="/cygdrive/c/code_red/RedSuite_4.2.3_379/redsuite/Tools/bin
# at those locations as well.
#export TOOLCHAIN_BIN="/usr/bin:/cygdrive/c/Program Files (x86)/Atollic/TrueSTUDIO for ARM Pro 2.3.0/ARMTools/bin"
#export TOOLCHAIN_BIN="/usr/bin:/cygdrive/c/Program Files (x86)/Atollic/TrueSTUDIO for STMicroelectronics STM32 Lite 2.3.0/ARMTools/bin"
+#export REDSUITE_BIN=
# This the Cygwin path to the location where I build the buildroot
# toolchain.
#export TOOLCHAIN_BIN="${WD}/../misc/buildroot/build_arm_nofpu/staging_dir/bin"
+#export REDSUITE_BIN=
-# Andd add the selected toolchain path to the PATH variable
+# And add the selected toolchain path[s] to the PATH variable
-export PATH="${TOOLCHAIN_BIN}:/sbin:/usr/sbin:${PATH_ORIG}"
+export PATH="/sbin:/usr/sbin:${PATH_ORIG}"
+
+if [ ! -z ${REDSUITE_BIN} ]; then
+ export PATH="${REDSUITE_BIN}:${PATH}"
+fi
+
+export PATH="${TOOLCHAIN_BIN}:${PATH}"
echo "PATH : ${PATH}"